@@ -9,6 +9,9 @@
 flux_fit_type <- function(df,
                           fit_type = c(),
                           fit_type_list = c(
+                            "exp_hm",
+                            "exp_tz",
+                            "exp_zhao18",
                             "exponential",
                             "linear",
                             "quadratic"
@@ -18,5 +21,14 @@ flux_fit_type <- function(df,
   } else {
     fit_type <- match.arg(fit_type, fit_type_list)
   }
+
+  if (is.null(fit_type)) {
+    stop("argument fit_type is missing")
+  }
+
+  if (fit_type == "exponential") {
+    fit_type <- "exp_zhao18" # for backwards compatibility
+  }
+
   fit_type
 }
