@@ -14,13 +14,15 @@
 #' @param cut_arg argument defining that the data point should be cut out
 #' @return a dataframe with the number of fluxes for each quality flags
 #' and their proportion to the total
-#' @importFrom dplyr .data all_of select group_by summarise
+#' @importFrom dplyr all_of select group_by summarise
 #' tibble right_join filter distinct
 #' @importFrom tidyr replace_na
 #' @author Vincent Belde
 #' @examples
-#' data(slopes30qua_flag)
-#' flux_flag_count(slopes30qua_flag)
+#' data(co2_conc)
+#' slopes <- flux_fitting(co2_conc, conc, datetime, fit_type = "exp_zhao18")
+#' slopes_flag <- flux_quality(slopes, conc)
+#' flux_flag_count(slopes_flag)
 #' @export
 
 
@@ -35,7 +37,9 @@ flux_flag_count <- function(slopes_df,
                               "force_discard",
                               "start_error",
                               "no_data",
-                              "force_ok"
+                              "force_ok",
+                              "force_zero",
+                              "force_lm"
                             ),
                             cut_arg = "cut") {
 
@@ -54,7 +58,7 @@ flux_flag_count <- function(slopes_df,
       n = length({{f_quality_flag}}),
       .by = {{f_quality_flag}}
     ) |>
-    right_join(flags, by = dplyr::join_by({{f_quality_flag}})) |>
+    right_join(flags, by = join_by({{f_quality_flag}})) |>
     mutate(
       n = replace_na(.data$n, 0),
       ratio = .data$n / sum(.data$n)
