@@ -12,7 +12,7 @@ flux_param_exp <- function(slopes_df,
   param_df <- slopes_df |>
     select(
       {{conc_col}}, "f_start", "f_fluxid", "f_RMSE", "f_cor_coef", "f_b",
-      "f_cut", "f_quality_flag"
+      "f_gfactor", "f_cut", "f_quality_flag"
     ) |>
     filter(.data$f_cut != "cut") |>
     select(!{{conc_col}}) |>
@@ -20,11 +20,14 @@ flux_param_exp <- function(slopes_df,
     mutate(
       f_RMSE = signif(.data$f_RMSE, digits = 2),
       f_cor_coef = signif(.data$f_cor_coef, digits = 2),
+      f_gfactor = signif(.data$f_gfactor, digits = 2),
       f_b = signif(.data$f_b, digits = 5),
       print_col = paste(
         .data$f_quality_flag, "\n",
-        "RMSE = ", .data$f_RMSE, "\n", "Corr coef = ",
-        .data$f_cor_coef, "\n", "b = ", .data$f_b,
+        "RMSE = ", .data$f_RMSE, "\n",
+        "Corr coef = ", .data$f_cor_coef, "\n",
+        "g-factor = ", .data$f_gfactor, "\n",
+        "b = ", .data$f_b,
         sep = ""
       )
     ) |>
